"""
Usage
=====
List devices connected to the onewire bus (W1-Bus).
    >>> w1 = W1Bus()
    >>> print w1.devices
    ['10-0008028d5c8a', 'w1_bus_master1']

Read temperature value of a connected device identified by the list index.
    >>> w1.read_value(0)
    29.312

@author: Stefan Lehmann
@version: 1.0.1
@summary: Access temperature sensors connected to the onewire bus.

"""


import os


W1_DEVICE_DIRECTORY = "/sys/bus/w1/devices"


class W1Bus():
    """
    Class for accessing the onewire bus of the Raspberry Pi

    @type devices: list
    @ivar devices: list of the connected devices, the index is the device id
    """
    def __init__(self):
        self.devices = []
        self.refresh()

    def filename(self, index):
        """
        Return the filename of the given sensor.
        @rtype: str
        """
        path_ = os.path.join(W1_DEVICE_DIRECTORY, self.devices[index])
        path_ = os.path.join(path_, "w1_slave")

        return path_

    def read_value(self, index):
        """
        Return the temperature of the sensor with the given index.
        @type index: int
        @param index: sensor index in the device list
        @rtype: float

        """

        with open(self.filename(index)) as f:
            text = f.read()
            second_line = text.split("\n")[1]
            temperature_data = second_line.split(" ")[9]
            temperature = float(temperature_data[2:]) / 1000.0
            return temperature

    def refresh(self):
        """
        Refresh W1 device list.
        """
        self.devices = os.listdir(W1_DEVICE_DIRECTORY)
#start kernel modules for onewire bus
os.system('sudo modprobe w1-gpio')
os.system('sudo modprobe w1-therm')